pysmug.methods

Package pysmug :: Module methods |
[hide private]
[frames] | no frames]

# Source Code for Module pysmug.methods

      1  # Copyright (c) 2008 Brian Zimmer <bzimmer@ziclix.com>
      2  #
      3  # Permission is hereby granted, free of charge, to any person obtaining a copy of
      4  # this software and associated documentation files (the "Software"), to deal in
      5  # the Software without restriction, including without limitation the rights to
      6  # use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
      7  # of the Software, and to permit persons to whom the Software is furnished to do
      8  # so, subject to the following conditions:
      9  #
     10  # The above copyright notice and this permission notice shall be included in all
     11  # copies or substantial portions of the Software.
     12  #
     13  # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
     14  # IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
     15  # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
     16  # AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
     17  # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
     18  # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
     19  # SOFTWARE.
     20
     21  apikeys = dict((x.lower(), x) for x in (
     22    "APIKey", "AlbumKey", "ImageKey",
     23    "FileName", "PasswordHash", "EmailAddress"
     24  ))
     25
     26  methods = set(
     27  ['smugmug.albums.applyWatermark',
     28   'smugmug.albums.changeSettings',
     29   'smugmug.albums.create',
     30   'smugmug.albums.delete',
     31   'smugmug.albums.get',
     32   'smugmug.albums.getInfo',
     33   'smugmug.albums.getStats',
     34   'smugmug.albums.reSort',
     35   'smugmug.albums.removeWatermark',
     36   'smugmug.albumtemplates.changeSettings',
     37   'smugmug.albumtemplates.create',
     38   'smugmug.albumtemplates.delete',
     39   'smugmug.albumtemplates.get',
     40   'smugmug.categories.create',
     41   'smugmug.categories.delete',
     42   'smugmug.categories.get',
     43   'smugmug.categories.rename',
     44   'smugmug.communities.get',
     45   'smugmug.communities.getAvailable',
     46   'smugmug.communities.join',
     47   'smugmug.communities.leave',
     48   'smugmug.communities.leaveAll',
     49   'smugmug.family.add',
     50   'smugmug.family.get',
     51   'smugmug.family.remove',
     52   'smugmug.family.removeAll',
     53   'smugmug.friends.add',
     54   'smugmug.friends.get',
     55   'smugmug.friends.remove',
     56   'smugmug.friends.removeAll',
     57   'smugmug.images.applyWatermark',
     58   'smugmug.images.changePosition',
     59   'smugmug.images.changeSettings',
     60   'smugmug.images.crop',
     61   'smugmug.images.delete',
     62   'smugmug.images.get',
     63   'smugmug.images.getEXIF',
     64   'smugmug.images.getInfo',
     65   'smugmug.images.getStats',
     66   'smugmug.images.getURLs',
     67   'smugmug.images.pricing',
     68   'smugmug.images.removeWatermark',
     69   'smugmug.images.rotate',
     70   #'smugmug.images.upload',
     71   'smugmug.images.uploadFromURL',
     72   'smugmug.images.zoomThumbnail',
     73   'smugmug.login.anonymously',
     74   'smugmug.login.withHash',
     75   'smugmug.login.withPassword',
     76   'smugmug.orders.get',
     77   'smugmug.orders.ship',
     78   'smugmug.propricing.getAlbum',
     79   'smugmug.propricing.getImage',
     80   'smugmug.propricing.getPortfolio',
     81   'smugmug.propricing.setAlbum',
     82   'smugmug.propricing.setImage',
     83   'smugmug.propricing.setPortfolio',
     84   'smugmug.sharegroups.addAlbum',
     85   'smugmug.sharegroups.changeSettings',
     86   'smugmug.sharegroups.create',
     87   'smugmug.sharegroups.delete',
     88   'smugmug.sharegroups.get',
     89   'smugmug.sharegroups.getInfo',
     90   'smugmug.sharegroups.removeAlbum',
     91   'smugmug.styles.getTemplates',
     92   'smugmug.subcategories.create',
     93   'smugmug.subcategories.delete',
     94   'smugmug.subcategories.get',
     95   'smugmug.subcategories.getAll',
     96   'smugmug.subcategories.rename',
     97   'smugmug.themes.get',
     98   'smugmug.users.getDisplayName',
     99   'smugmug.users.getTransferStats',
    100   'smugmug.users.getTree',
    101   'smugmug.watermarks.changeSettings',
    102   'smugmug.watermarks.createnew',
    103   'smugmug.watermarks.delete',
    104   'smugmug.watermarks.get',
    105   'smugmug.watermarks.getInfo'
    106  ])
    107